@@ -12,12 +12,12 @@ import sys
 from pathlib import Path
 
 # Importar componentes modulares
-from .core.application_config import ApplicationConfig
-from .core.data_manager import DataManager
-from .core.status_manager import StatusManager
-from .gui.menu_manager import MenuManager
-from .gui.main_interface import MainInterface
-from .gui.dialogs.dialog_manager import DialogManager
+from .app_configs.application_config import ApplicationConfig
+from .app_configs.data_manager import DataManager
+from .app_configs.status_manager import StatusManager
+from vacancy_predictor.gui.app_configs.menu_manager import MenuManager
+from vacancy_predictor.gui.app_configs.main_interface import MainInterface
+from .app_configs.dialog_manager import DialogManager
 
 logger = logging.getLogger(__name__)
 
